==> pint_1.0.0.tar.gz: pint/R/AllGenerics.R <==
setGeneric("setLoc<-",function(model,value){standardGeneric("setLoc<-")}) 
setGeneric("setGeneName<-",function(model,value){standardGeneric("setGeneName<-")}) 
setGeneric("setChromosome<-",function(model, value){standardGeneric ("setChromosome<-")})
setGeneric("setArm<-",function(model, value){standardGeneric ("setArm<-")})
setGeneric("getW",function(model){standardGeneric ("getW")}) 
setGeneric("getPhi",function(model){standardGeneric ("getPhi")}) 
setGeneric("getScore",function(model){standardGeneric ("getScore")}) 
setGeneric("getLoc",function(model){standardGeneric ("getLoc")}) 
setGeneric("getGeneName",function(model){standardGeneric ("getGeneName")}) 
setGeneric("getChromosome",function(model){standardGeneric ("getChromosome")}) 
setGeneric("getArm",function(model){standardGeneric ("getArm")}) 
setGeneric("getModelMethod",function(model){standardGeneric ("getModelMethod")}) 
setGeneric("getParams",function(model){standardGeneric ("getParams")}) 
setGeneric("getPArm",function(model){standardGeneric ("getPArm")}) 
setGeneric("getQArm",function(model){standardGeneric ("getQArm")}) 
setGeneric("getWindowSize",function(model){standardGeneric ("getWindowSize")})
setGeneric("topGenes",function(model,num){standardGeneric ("topGenes")}) 
setGeneric("topModels",function(model,num){standardGeneric ("topModels")}) 
setGeneric("getModelNumbers",function(model){standardGeneric ("getModelNumbers")})
setGeneric("isEmpty",function(model){standardGeneric ("isEmpty")})
setGeneric("orderGenes",function(model){standardGeneric ("orderGenes")})
setGeneric("findModel",function(model, name){standardGeneric ("findModel")})

==> pint_1.16.0.tar.gz: pint/R/AllGenerics.R <==
setGeneric("setLoc<-",function(model,value){standardGeneric("setLoc<-")}) 
setGeneric("setGeneName<-",function(model,value){standardGeneric("setGeneName<-")}) 
setGeneric("setChromosome<-",function(model, value){standardGeneric ("setChromosome<-")})
setGeneric("setArm<-",function(model, value){standardGeneric ("setArm<-")})
setGeneric("getW",function(model){standardGeneric ("getW")}) 
setGeneric("getPhi",function(model){standardGeneric ("getPhi")}) 
setGeneric("getScore",function(model){standardGeneric ("getScore")}) 
setGeneric("getLoc",function(model){standardGeneric ("getLoc")}) 
setGeneric("getGeneName",function(model){standardGeneric ("getGeneName")}) 
setGeneric("getGeneNames",function(model){standardGeneric ("getGeneNames")}) 
setGeneric("getChromosome",function(model){standardGeneric ("getChromosome")}) 
setGeneric("getArm",function(model){standardGeneric ("getArm")}) 
setGeneric("getModelMethod",function(model){standardGeneric ("getModelMethod")}) 
setGeneric("getParams",function(model){standardGeneric ("getParams")}) 
setGeneric("getPArm",function(model){standardGeneric ("getPArm")}) 
setGeneric("getQArm",function(model){standardGeneric ("getQArm")}) 
setGeneric("getWindowSize",function(model){standardGeneric ("getWindowSize")})
setGeneric("topGenes",function(model,num = NA){standardGeneric ("topGenes")}) 
setGeneric("topModels",function(model,num = 1){standardGeneric ("topModels")}) 
setGeneric("getModelNumbers",function(model){standardGeneric ("getModelNumbers")})
setGeneric("isEmpty",function(model){standardGeneric ("isEmpty")})
setGeneric("orderGenes",function(model){standardGeneric ("orderGenes")})
setGeneric("findModel",function(model, name){standardGeneric ("findModel")})
